## Copyright (C) 2009, 2010 Thomas Weidenfeller
## 
## This file is part of gds2000tools/gds-octave.
## 
## gds2000tools/gds-octave is free software: you can redistribute it
## and/or modify it under the terms of the GNU General Public License
## version 3 as published by the Free Software Foundation.
## 
## gds2000tools/gds-octave is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with gds2000tools/gds-octave.  If not,
## see <http://www.gnu.org/licenses/>.
##

## usage: [GDSSTRUCT_INV] = gds_inv(GDSSTRUCT)
## usage: gds_inv(GDSSTRUCT)
##
## Create an inverted version of the waveform data. This is, for example,
## useful if the data was accidentally acquired inverted.
##
## GDSSTRUCT.Waveform_Data, GDSSTRUCT.Trigger_Level, and 
## GDSSTRUCT.Vertical_Position are inverted.
##
## If no return value is requested then the data is plotted instead.
##
## Example:
##
## gs = gds_csvread("DS0008.CSV");
## subplot (2,1,1);
## gds_plot(gs);
## subplot (2,1,2);
## gds_inv(gs);
##
## See also: gds_csvread, gds_csvwrite.

## Author: Thomas Weidenfeller
## Created: 2009-07-08
## Version: $Id: gds_inv.m,v 1.8 2010/12/31 13:05:40 tw Exp $
## Keywords: Oscilloscope, GDS-2000, gds2000tools, invert

function [gsout] = gds_inv(gs)

	if(nargin != 1 || !isstruct(gs))
		print_usage();
	endif

	gs.Waveform_Data     = gs.Waveform_Data .* -1;
	gs.Trigger_Level     = gs.Trigger_Level .* -1;
	gs.Vertical_Position = gs.Vertical_Position .* -1;
	gs.Source            = [ gs.Source "-Inv" ];

	if(nargout < 1)
		gds_plot(gs);
	else
		gsout = gs;
	endif
endfunction

%!demo
%! ##gs = gds_csvread("DS0008.CSV"); ## read waveform from file
%! gs = __gds_demo_gs();  ## for now get a demo gds waveform data structure
%! subplot (2,1,1);
%! gds_plot(gs);
%! subplot (2,1,2);
%! gds_inv(gs);
